==> resh-5.0.0.16-py3-none-any.whl: resh/utils/const.py <==
RESH_BUILD = 16
RESH_VERSION = f'5.0.0.{RESH_BUILD}'

VER = f"""
     AAAAAA  WWWW               WWWW  AAAAAA      DDDDDDDDDD        AAAAAA     
    AAAAAAAA  WWWW    WWWWW    WWWW  AAAAAAAA     DDDDDDDDDDDD     AAAAAAAA    
   AAAAAAAAAA  WWWW WWWWWWWWW WWWW  AAAAAAAAAA    DDDD    DDDD    AAAAAAAAAA   
  AAAAA  AAAAA  WWWWWWWW WWWWWWWW  AAAAA  AAAAA   DDDD    DDDD   AAAAA  AAAAA  
 AAAAA    AAAAA  WWWWWW   WWWWWW  AAAAA    AAAAA  DDDDDDDDDDDD  AAAAA    AAAAA 
AAAAA      AAAAA  WWWW     WWWW  AAAAA      AAAAA DDDDDDDDDD   AAAAA      AAAAA
===============================================================================
{('v' + RESH_VERSION).rjust(79, ' ')}
                                                              (C) AWADA Systems
                                                Resh - Rapida Engineering Shell
"""

"""Domains"""
MODULE_DOMAIN = 'module'
SYSTEM = 'system'
CONFIG = 'config'
GATEWAY = 'gateway'
BRIDGE = 'bridge'
DALI = 'dali'
DALI2 = 'dali2'
EVENT = 'event'
SYS = 'system'
MERCURY = 'mercury'

"""Parameters"""
CLASS = 'Class'
MODULE_0_31 = 'Module*'
MODULE = 'Module'
CHANNEL = 'Channel'
DEVICE_ADDR = 'Address'
DEVICE_TYPE = 'Type'
INSTANCE = 'Instance'
NAME = 'Name'
BYTES_ARR = '...Bytes'
BYTE_ADDR = 'Address|AddressByte'
BYTE_INSTANCE = 'Instance|InstanceByte'
BYTE_OPCODE = 'Opcode'
DTR0_VALUE = 'Dtr0Value'
TIME = 'Time'
TIMEOUT = 'TimeOut'
IP = 'IP'
ATTRIBUTES = '...Attributes'
PORT = 'Port'
GATEWAY_VAR = 'Gateway'
MASK_LC = 'Mask'
DNS = 'Dns'
DNS2 = 'Dns2'
HOURS = 'Hours'
MINUTES = 'Minutes'
SECONDS = 'Seconds'
TZ = 'TimeZone'
DAY = 'Day'
MONTH = 'Month'
YEAR = 'Year'
NEW_ADDRESS = 'NewAddress'
FILE = 'File'
MEMORY_BANK = 'MemoryBank'
MEMORY_LOCATION = 'MemoryLocation'
MEMORY_VALUE = 'MemoryValue'
SCENE_NUMBER = 'SceneNumber'
LEVEL = 'Level'
FADE_RATE = 'FadeRate'
FADE_TIME = 'FadeTime'
OPERATING_MODE = 'Mode'
EVENT_PRIORITY = 'EventPriority'
EVENT_FILTER = 'EventFilter'
EVENT_SCHEME = 'EventScheme'
DIMMING_CURVE = 'DimmingCurve'
TEMPERATURE = 'Temperature'
GROUP_ID = 'GroupId'
GROUP_IDs = '...GroupId`s'
MODE = 'Mode'
START_ADDRESS = 'StartAddress'
HYSTERESIS = 'Hysteresis'
HYSTERESIS_MIN = 'HysteresisMin'
HOLD_TIME = 'HoldTime'
DEAD_TIME = 'DeadTimer'
REPORT_TIME = 'ReportTime'
ADDRESS1 = 'Address1'
ADDRESS2 = 'Address2'
SHORT_ADDRESS = 'ShortAddress'
GATEWAY_IDs = '...GatewaysId`s'
NAMED_PARAMS_DESC = 'named_params_desc'
EXCLUDE_PARAMS_DESC = 'exclude_params_desc'
BROADCAST_VALUE = 'broadcast_value'
CAN = 'Can'

"""Parameter values"""
SEND_TWICE = 'ST'
MASK = 'MASK'
MODE_CROSS = 'CROSS'
MODE_NOCROSS = 'NOCROSS'

"""tools"""
DEF_PARAMS = 'def_params'
DESC = 'desc'

""" Modbus """
BAUD = 'Baud'
PARITY = 'Parity'
STOP_BITS = 'StopBits'


BUS_TYPE = 'socketcan'

==> resh-5.1.0.9-py3-none-any.whl: resh/utils/const.py <==
from resh.version import VERSION


VER = f"""
     AAAAAA  WWWW               WWWW  AAAAAA      DDDDDDDDDD        AAAAAA     
    AAAAAAAA  WWWW    WWWWW    WWWW  AAAAAAAA     DDDDDDDDDDDD     AAAAAAAA    
   AAAAAAAAAA  WWWW WWWWWWWWW WWWW  AAAAAAAAAA    DDDD    DDDD    AAAAAAAAAA   
  AAAAA  AAAAA  WWWWWWWW WWWWWWWW  AAAAA  AAAAA   DDDD    DDDD   AAAAA  AAAAA  
 AAAAA    AAAAA  WWWWWW   WWWWWW  AAAAA    AAAAA  DDDDDDDDDDDD  AAAAA    AAAAA 
AAAAA      AAAAA  WWWW     WWWW  AAAAA      AAAAA DDDDDDDDDD   AAAAA      AAAAA
===============================================================================
{('v' + VERSION).rjust(79, ' ')}
                                                              (C) AWADA Systems
                                                Resh - Rapida Engineering Shell
"""

"""Domains"""
MODULE_DOMAIN = 'module'
SYSTEM = 'system'
CONFIG = 'config'
GATEWAY = 'gateway'
BRIDGE = 'bridge'
DALI = 'dali'
DALI2 = 'dali2'
EVENT = 'event'
SYS = 'system'
MERCURY = 'mercury'

"""Parameters"""
CLASS = 'Class'
MODULE_0_31 = 'Module*'
MODULE = 'Module'
CHANNEL = 'Channel'
DEVICE_ADDR = 'Address'
DEVICE_TYPE = 'Type'
INSTANCE = 'Instance'
NAME = 'Name'
BYTES_ARR = '...Bytes'
BYTE_ADDR = 'Address|AddressByte'
BYTE_INSTANCE = 'Instance|InstanceByte'
BYTE_OPCODE = 'Opcode'
DTR0_VALUE = 'Dtr0Value'
TIME = 'Time'
TIMEOUT = 'TimeOut'
IP = 'IP'
ATTRIBUTES = '...Attributes'
PORT = 'Port'
GATEWAY_VAR = 'Gateway'
MASK_LC = 'Mask'
DNS = 'Dns'
DNS2 = 'Dns2'
HOURS = 'Hours'
MINUTES = 'Minutes'
SECONDS = 'Seconds'
TZ = 'TimeZone'
DAY = 'Day'
MONTH = 'Month'
YEAR = 'Year'
NEW_ADDRESS = 'NewAddress'
FILE = 'File'
MEMORY_BANK = 'MemoryBank'
MEMORY_LOCATION = 'MemoryLocation'
MEMORY_VALUE = 'MemoryValue'
SCENE_NUMBER = 'SceneNumber'
LEVEL = 'Level'
FADE_RATE = 'FadeRate'
FADE_TIME = 'FadeTime'
OPERATING_MODE = 'Mode'
EVENT_PRIORITY = 'EventPriority'
EVENT_FILTER = 'EventFilter'
EVENT_SCHEME = 'EventScheme'
DIMMING_CURVE = 'DimmingCurve'
TEMPERATURE = 'Temperature'
GROUP_ID = 'GroupId'
GROUP_IDs = '...GroupId`s'
MODE = 'Mode'
START_ADDRESS = 'StartAddress'
HYSTERESIS = 'Hysteresis'
HYSTERESIS_MIN = 'HysteresisMin'
HOLD_TIME = 'HoldTime'
DEAD_TIME = 'DeadTimer'
REPORT_TIME = 'ReportTime'
ADDRESS1 = 'Address1'
ADDRESS2 = 'Address2'
SHORT_ADDRESS = 'ShortAddress'
GATEWAY_IDs = '...GatewaysId`s'
NAMED_PARAMS_DESC = 'named_params_desc'
EXCLUDE_PARAMS_DESC = 'exclude_params_desc'
BROADCAST_VALUE = 'broadcast_value'
CAN = 'Can'
COUNT = 'Count'
COMMAND = 'Command'
ADDRESSES = 'Addresses'

SORT_BY_ADDR = '-a'
FORCED = '--forced'

"""Parameter values"""
SEND_TWICE = 'ST'
MASK = 'MASK'
MODE_CROSS = 'CROSS'
MODE_NOCROSS = 'NOCROSS'

"""tools"""
DEF_PARAMS = 'def_params'
DESC = 'desc'

""" Modbus """
BAUD = 'Baud'
PARITY = 'Parity'
STOP_BITS = 'StopBits'


BUS_TYPE = 'socketcan'
